@@ -18,18 +18,11 @@ As such, `cargo-script` does two major things:
 
 2. It caches the generated and compiled packages, regenerating them only if the script or its metadata have changed.
 */
-extern crate clap;
 extern crate env_logger;
 #[macro_use]
 extern crate lazy_static;
 #[macro_use]
 extern crate log;
-extern crate open;
-extern crate regex;
-extern crate serde;
-extern crate shaman;
-extern crate toml;
-
 #[macro_use]
 extern crate crossbeam_channel;
 
@@ -65,6 +58,7 @@ use std::process::{self, Command};
 
 use crate::error::{Blame, MainError, Result};
 use crate::util::{ChainMap, Defer};
+use sha1::{Digest, Sha1};
 
 #[derive(Debug)]
 struct Args {
@@ -126,7 +120,7 @@ impl BuildKind {
 fn parse_args() -> Args {
     use clap::{App, Arg, ArgGroup};
     let version = option_env!("CARGO_PKG_VERSION").unwrap_or("unknown");
-    let about = r#"Compiles and rtuns a Rust script."#;
+    let about = r#"Compiles and runs a Rust script."#;
 
     // We have to kinda lie about who we are for the output to look right...
     let m = App::new("rust-script")
@@ -1258,17 +1252,15 @@ impl<'a> Input<'a> {
         DepIt: IntoIterator<Item = (&'dep str, &'dep str)>,
     {
         use crate::Input::*;
-        use shaman::digest::Digest;
-        use shaman::sha1::Sha1;
 
         let hash_deps = || {
             let mut hasher = Sha1::new();
             for dep in deps {
-                hasher.input_str("dep=");
-                hasher.input_str(dep.0);
-                hasher.input_str("=");
-                hasher.input_str(dep.1);
-                hasher.input_str(";");
+                hasher.update(b"dep=");
+                hasher.update(dep.0);
+                hasher.update(b"=");
+                hasher.update(dep.1);
+                hasher.update(b";");
             }
             hasher
         };
@@ -1278,8 +1270,8 @@ impl<'a> Input<'a> {
                 let mut hasher = Sha1::new();
 
                 // Hash the path to the script.
-                hasher.input_str(&path.to_string_lossy());
-                let mut digest = hasher.result_str();
+                hasher.update(&*path.to_string_lossy());
+                let mut digest = format!("{:x}", hasher.finalize());
                 digest.truncate(consts::ID_DIGEST_LEN_MAX);
 
                 let mut id = OsString::new();
@@ -1292,12 +1284,12 @@ impl<'a> Input<'a> {
             Expr(content, template) => {
                 let mut hasher = hash_deps();
 
-                hasher.input_str("template:");
-                hasher.input_str(template.unwrap_or(""));
-                hasher.input_str(";");
+                hasher.update("template:");
+                hasher.update(template.unwrap_or(""));
+                hasher.update(";");
 
-                hasher.input_str(content);
-                let mut digest = hasher.result_str();
+                hasher.update(content);
+                let mut digest = format!("{:x}", hasher.finalize());
                 digest.truncate(consts::ID_DIGEST_LEN_MAX);
 
                 let mut id = OsString::new();
@@ -1309,11 +1301,11 @@ impl<'a> Input<'a> {
                 let mut hasher = hash_deps();
 
                 // Make sure to include the [non-]presence of the `--count` flag in the flag, since it changes the actual generated script output.
-                hasher.input_str("count:");
-                hasher.input_str(if count { "true;" } else { "false;" });
+                hasher.update("count:");
+                hasher.update(if count { "true;" } else { "false;" });
 
-                hasher.input_str(content);
-                let mut digest = hasher.result_str();
+                hasher.update(content);
+                let mut digest = format!("{:x}", hasher.finalize());
                 digest.truncate(consts::ID_DIGEST_LEN_MAX);
 
                 let mut id = OsString::new();
@@ -1329,11 +1321,9 @@ impl<'a> Input<'a> {
 Shorthand for hashing a string.
 */
 fn hash_str(s: &str) -> String {
-    use shaman::digest::Digest;
-    use shaman::sha1::Sha1;
     let mut hasher = Sha1::new();
-    hasher.input_str(s);
-    hasher.result_str()
+    hasher.update(s);
+    format!("{:x}", hasher.finalize())
 }
 
 enum FileOverwrite {
